==> juffed-debuginfo-0.10-2.tar.xz: usr/src/debug/juffed-0.10-2/plugins/doclist/qrc_doclistplugin.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/juffed/juffed-0.10-2.x86_64/src/juffed-0.10/plugins/doclist/doc_icon.png
  0x0,0x0,0x1,0xe3,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x1,0x83,0x49,0x44,0x41,0x54,0x38,
  0xcb,0x7d,0x52,0x4b,0x8a,0xeb,0x30,0x10,0x2c,0x75,0xcb,0x81,0xf0,0x8,0xf6,0x22,
  0x8b,0xc0,0x1c,0x25,0x64,0xf1,0xe6,0x4,0x73,0xad,0x9c,0x20,0x97,0xc8,0x1d,0x5e,
  0x2e,0x90,0x5d,0xae,0x60,0x8,0xc9,0x66,0x42,0xc0,0x1f,0x59,0xdd,0x9a,0x55,0xeb,
  0x29,0x66,0x66,0xa,0x44,0xb7,0xd,0xaa,0x2e,0x55,0xb5,0x3,0x80,0xfd,0x7e,0xf,
  0x0,0x35,0x33,0x37,0xcc,0x8c,0x10,0x2,0x86,0x61,0x40,0xdf,0xf7,0xb9,0xaa,0x2a,
  0xc,0x7d,0xdf,0xc7,0xe7,0xf3,0x79,0x65,0x66,0x71,0x87,0xc3,0x1,0xf7,0xfb,0xfd,
  0xcf,0x6e,0xb7,0x3b,0x34,0x4d,0xf3,0xe,0x40,0x54,0x15,0x22,0x2,0x11,0x81,0xf5,
  0x6,0x22,0xa2,0xf3,0xf9,0xdc,0x1e,0x8f,0xc7,0x8f,0xf5,0x7a,0x7d,0xf5,0x31,0x46,
  0x0,0x68,0x56,0xab,0xd5,0xdf,0xcd,0x66,0xf3,0x26,0x22,0x70,0xce,0xe5,0x43,0x44,
  0x20,0xa2,0xfc,0x5d,0x55,0x15,0x6e,0xb7,0x1b,0x1e,0x8f,0x7,0xd7,0x75,0xd,0x2f,
  0x22,0x88,0x31,0xc2,0xaa,0xaa,0xc2,0x39,0x67,0xd3,0x90,0x52,0x42,0x4a,0x29,0x13,
  0x30,0x73,0xae,0xcc,0xc,0x3f,0x4d,0x13,0xa6,0x69,0x82,0xaa,0x82,0x88,0x0,0x0,
  0xce,0xb9,0x97,0x4b,0xa6,0xa4,0x54,0x54,0x55,0x15,0xbc,0xf7,0xf0,0x21,0x4,0x8c,
  0xe3,0x8,0x55,0x45,0x8,0x21,0x33,0x1b,0x11,0x33,0xe7,0xcb,0x25,0x52,0x4a,0x0,
  0xf0,0x9f,0x40,0x44,0xb0,0x58,0x2c,0xb2,0xf4,0x52,0xb2,0x29,0x4b,0x29,0xe5,0xde,
  0xf0,0x42,0xc0,0xcc,0xd9,0x83,0x52,0x76,0x39,0xdd,0x3c,0xb1,0xde,0x5b,0xe6,0x73,
  0xf,0xca,0x63,0xb0,0xde,0xe2,0x55,0x55,0xf8,0x71,0x1c,0xb3,0x2,0xcb,0xfb,0x3b,
  0x5,0x46,0x6e,0xc9,0x58,0x72,0x64,0xa,0x2c,0x46,0x23,0x98,0xbb,0x5e,0xee,0x83,
  0x3d,0x23,0x2b,0x18,0x86,0x1,0x31,0x46,0x2c,0x97,0xcb,0x97,0x3d,0x98,0x2f,0x53,
  0xf9,0x2f,0xf,0x32,0x2,0x11,0xc9,0xcc,0x66,0x52,0x89,0x9f,0xcc,0xcc,0x29,0xa4,
  0x94,0xe0,0xbd,0x87,0xaa,0xe6,0x6d,0x9b,0x4b,0x9f,0x1b,0x4c,0x44,0xf0,0x0,0x10,
  0x42,0xf8,0x6c,0xdb,0xf6,0xdf,0xe9,0x74,0x7a,0x7,0x20,0xf3,0xa5,0x99,0x25,0x41,
  0x97,0xcb,0xa5,0x25,0x22,0xe9,0xba,0xe,0xe,0x0,0xb6,0xdb,0x2d,0x0,0xd4,0xce,
  0xb9,0xc6,0x4c,0xfa,0xd,0xe3,0x38,0xc6,0xae,0xeb,0xae,0x44,0x24,0x5f,0x2d,0xf1,
  0x20,0x90,0x8f,0x6f,0x3f,0xe9,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,
  0x60,0x82,
    // /usr/src/ports/juffed/juffed-0.10-2.x86_64/src/juffed-0.10/plugins/doclist/edit-clear.png
  0x0,0x0,0x3,0x5,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,0x70,0x65,0x2e,0x6f,0x72,
  0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x2,0x97,0x49,0x44,0x41,0x54,0x38,0x8d,0x95,
  0x92,0x4b,0x68,0x94,0x67,0x14,0x86,0x9f,0xef,0x9b,0x99,0xe8,0x4c,0x12,0x9b,0xdb,
  0x48,0x42,0x93,0x48,0xbc,0xd5,0xa8,0x14,0x2b,0x26,0x8b,0xa,0xd2,0x82,0x8b,0x4a,
  0x4b,0x76,0x82,0x97,0x85,0x8b,0xd1,0x8d,0x82,0x22,0xfc,0xb,0x5,0x5d,0x18,0x17,
  0x6,0x1c,0x90,0x52,0x10,0x84,0x8e,0xc6,0x85,0x60,0x4b,0x75,0xa1,0xb,0xe9,0x8d,
  0x16,0x31,0x2d,0xb4,0x69,0x34,0x31,0x8a,0x31,0x8d,0x9a,0x71,0x46,0x49,0x93,0xc9,
  0x65,0xcc,0x3f,0xf3,0x4f,0xfe,0xff,0xfb,0x8e,0x2b,0x45,0x63,0x21,0xf8,0xac,0xcf,
  0xfb,0x70,0xce,0xcb,0x51,0x47,0xbe,0x60,0x73,0x38,0xc4,0x5,0x11,0xa2,0xc6,0xb2,
  0xf7,0xd4,0xd,0xf9,0x91,0xf7,0x40,0x87,0x34,0xdf,0xaf,0x6d,0x8e,0xad,0xda,0xb0,
  0xa2,0xbc,0x31,0xa4,0xb9,0x7a,0x74,0x9b,0xda,0xfa,0x5e,0x2,0x60,0x71,0x45,0x54,
  0xb3,0xb4,0x2a,0xc2,0xc7,0x2d,0xb1,0x58,0x48,0x73,0xf6,0xf4,0x7e,0xa5,0x53,0x49,
  0xd5,0x99,0x4a,0xaa,0xda,0x5,0x5,0x56,0xe8,0x1c,0x7c,0x52,0x74,0x7d,0x23,0xd4,
  0xd7,0x94,0x11,0x5d,0xac,0xea,0xab,0x1a,0xe9,0x5,0x8e,0x3,0x4b,0x17,0x14,0x88,
  0xf0,0x8d,0xeb,0x99,0x8b,0xb7,0x6,0xf3,0xee,0x4c,0xc9,0xa7,0xa9,0x9d,0xca,0x95,
  0xad,0x1b,0x37,0xc4,0xe3,0x4d,0x2f,0x80,0xba,0x85,0x4,0x4a,0x44,0x0,0xe8,0xda,
  0xa7,0x4e,0xc4,0x57,0x72,0xfc,0x93,0xb6,0xcf,0x55,0x73,0x4b,0x3b,0x3d,0xa7,0xbb,
  0xbd,0xe9,0x7f,0xc6,0x72,0xec,0x54,0x93,0xc6,0xc8,0x25,0x11,0xce,0x27,0x1c,0x19,
  0xff,0x5f,0x41,0x2a,0xa9,0x76,0x69,0xad,0xbe,0xfd,0x74,0x73,0x47,0xb4,0xae,0xae,
  0x81,0x7f,0xbf,0xfe,0x9b,0xa7,0x57,0x1f,0xb2,0xfe,0xec,0x76,0x6a,0xd7,0x55,0x91,
  0x1e,0xed,0xf7,0xee,0xdf,0xfd,0x43,0x8c,0xf5,0xbe,0x33,0x46,0x8e,0x25,0x1c,0xc9,
  0xce,0x17,0xec,0xd1,0x9a,0x64,0x53,0x7d,0x6b,0x39,0x97,0x24,0x6a,0x26,0x5d,0xb6,
  0x74,0x6f,0x65,0x51,0x8d,0x6,0x15,0x85,0x50,0x35,0x7e,0x50,0xce,0xbd,0xc1,0x5f,
  0xfd,0x81,0xfe,0xdf,0xd,0xe2,0xff,0x60,0xc,0x29,0xe0,0xe6,0xeb,0x13,0x52,0x49,
  0xb5,0x28,0x72,0x8e,0x3b,0x15,0xcd,0xb5,0xab,0x3a,0x2e,0x1f,0xe,0x69,0xfd,0x1c,
  0x42,0xd,0x60,0xc6,0xc0,0x64,0xb1,0x41,0x1e,0xcf,0xb6,0xe0,0xcd,0xd5,0x90,0xc9,
  0xc,0xc8,0xe3,0x91,0x1,0x77,0x6a,0x32,0x5b,0xd4,0xaf,0x56,0x49,0x38,0x52,0xf2,
  0x77,0xd3,0x55,0x7b,0xb0,0xb1,0xa4,0x23,0x65,0x60,0x67,0x21,0x18,0x1,0x93,0x5,
  0xf3,0x1f,0x5e,0xe1,0x19,0xb3,0xb9,0xeb,0xcc,0x8c,0x9d,0x23,0x5e,0x8d,0xda,0xd4,
  0xfe,0x55,0x85,0x56,0x4a,0xc2,0x6f,0x35,0x52,0xc1,0xcf,0xd9,0x4c,0x5a,0x5b,0xab,
  0x50,0xfe,0x8,0x22,0x3e,0xfe,0x9c,0x87,0x57,0x9a,0xa5,0x58,0x98,0xa1,0x50,0x98,
  0x46,0x44,0xd0,0xe1,0x4a,0xd2,0x4f,0x7a,0x3,0x94,0xfc,0xa6,0xdf,0xcc,0x27,0x1c,
  0x79,0xe6,0xcf,0x4d,0x8f,0xa4,0xd3,0x77,0x99,0x71,0x63,0x4c,0x4c,0x8c,0x92,0xcb,
  0xa5,0x99,0xcc,0x65,0x70,0xdd,0x29,0x44,0x84,0x58,0xf5,0x36,0xa,0x45,0xcd,0xd0,
  0x83,0xfe,0x92,0x31,0x38,0x6f,0x9,0x0,0x2,0x23,0x87,0xfa,0x7a,0x7f,0x29,0xfa,
  0xac,0xc6,0x75,0x3d,0x8a,0xc5,0x3c,0xd6,0x6,0xe8,0x70,0xd,0x95,0xf1,0x1d,0xe4,
  0xdd,0x98,0xdc,0xba,0x79,0x25,0x6f,0x4c,0xf0,0x65,0xc2,0x91,0xcc,0xeb,0x12,0xdf,
  0xa4,0xfb,0x8c,0xea,0x59,0xfd,0x51,0x7b,0xdb,0xf2,0x15,0xad,0x11,0x2f,0xff,0x27,
  0x65,0xb1,0x35,0xe8,0xc8,0x32,0x1e,0xd,0xf7,0x4,0x43,0x43,0x7d,0xe3,0xd6,0xf2,
  0x59,0xc2,0x91,0x87,0x0,0xe1,0x77,0xd2,0x80,0x31,0x74,0xc,0x3d,0xf8,0xeb,0x76,
  0xe5,0x92,0x86,0xf,0x3f,0xa8,0x6a,0xd3,0xa3,0xa3,0xf7,0xfc,0xe1,0xe1,0x9f,0x2,
  0x6b,0xbc,0xeb,0xd6,0x72,0x20,0xe1,0xc8,0xc4,0x3b,0x9f,0x38,0x9f,0x54,0x52,0x2d,
  0x53,0x8a,0x3e,0xa5,0x10,0xe0,0x9a,0xb5,0x9c,0x4c,0x38,0xf2,0x78,0xfe,0xdc,0x4b,
  0x7e,0x7,0x43,0x8,0x28,0x84,0x12,0xda,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,
  0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // doc_icon
  0x0,0x8,
  0x5,0x95,0xf7,0x3e,
  0x0,0x64,
  0x0,0x6f,0x0,0x63,0x0,0x5f,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,
    // clear
  0x0,0x5,
  0x0,0x6a,0x2b,0x82,
  0x0,0x63,
  0x0,0x6c,0x0,0x65,0x0,0x61,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
  // :/clear
  0x0,0x0,0x0,0x16,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xe7,
  // :/doc_icon
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_doclistplugin)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_doclistplugin))

int QT_MANGLE_NAMESPACE(qCleanupResources_doclistplugin)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_doclistplugin))

==> juffed-debuginfo-0.10-3.tar.xz: usr/src/debug/juffed-0.10-3/plugins/doclist/qrc_doclistplugin.cxx <==
/****************************************************************************
** Resource object code
**
** Created by: The Resource Compiler for Qt version 4.8.7
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtCore/qglobal.h>

static const unsigned char qt_resource_data[] = {
  // /usr/src/ports/juffed/juffed-0.10-3.i686/src/juffed-0.10/plugins/doclist/doc_icon.png
  0x0,0x0,0x1,0xe3,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x6,0x62,0x4b,0x47,0x44,0x0,0xff,0x0,0xff,0x0,0xff,0xa0,0xbd,
  0xa7,0x93,0x0,0x0,0x0,0x9,0x70,0x48,0x59,0x73,0x0,0x0,0x0,0x48,0x0,0x0,
  0x0,0x48,0x0,0x46,0xc9,0x6b,0x3e,0x0,0x0,0x1,0x83,0x49,0x44,0x41,0x54,0x38,
  0xcb,0x7d,0x52,0x4b,0x8a,0xeb,0x30,0x10,0x2c,0x75,0xcb,0x81,0xf0,0x8,0xf6,0x22,
  0x8b,0xc0,0x1c,0x25,0x64,0xf1,0xe6,0x4,0x73,0xad,0x9c,0x20,0x97,0xc8,0x1d,0x5e,
  0x2e,0x90,0x5d,0xae,0x60,0x8,0xc9,0x66,0x42,0xc0,0x1f,0x59,0xdd,0x9a,0x55,0xeb,
  0x29,0x66,0x66,0xa,0x44,0xb7,0xd,0xaa,0x2e,0x55,0xb5,0x3,0x80,0xfd,0x7e,0xf,
  0x0,0x35,0x33,0x37,0xcc,0x8c,0x10,0x2,0x86,0x61,0x40,0xdf,0xf7,0xb9,0xaa,0x2a,
  0xc,0x7d,0xdf,0xc7,0xe7,0xf3,0x79,0x65,0x66,0x71,0x87,0xc3,0x1,0xf7,0xfb,0xfd,
  0xcf,0x6e,0xb7,0x3b,0x34,0x4d,0xf3,0xe,0x40,0x54,0x15,0x22,0x2,0x11,0x81,0xf5,
  0x6,0x22,0xa2,0xf3,0xf9,0xdc,0x1e,0x8f,0xc7,0x8f,0xf5,0x7a,0x7d,0xf5,0x31,0x46,
  0x0,0x68,0x56,0xab,0xd5,0xdf,0xcd,0x66,0xf3,0x26,0x22,0x70,0xce,0xe5,0x43,0x44,
  0x20,0xa2,0xfc,0x5d,0x55,0x15,0x6e,0xb7,0x1b,0x1e,0x8f,0x7,0xd7,0x75,0xd,0x2f,
  0x22,0x88,0x31,0xc2,0xaa,0xaa,0xc2,0x39,0x67,0xd3,0x90,0x52,0x42,0x4a,0x29,0x13,
  0x30,0x73,0xae,0xcc,0xc,0x3f,0x4d,0x13,0xa6,0x69,0x82,0xaa,0x82,0x88,0x0,0x0,
  0xce,0xb9,0x97,0x4b,0xa6,0xa4,0x54,0x54,0x55,0x15,0xbc,0xf7,0xf0,0x21,0x4,0x8c,
  0xe3,0x8,0x55,0x45,0x8,0x21,0x33,0x1b,0x11,0x33,0xe7,0xcb,0x25,0x52,0x4a,0x0,
  0xf0,0x9f,0x40,0x44,0xb0,0x58,0x2c,0xb2,0xf4,0x52,0xb2,0x29,0x4b,0x29,0xe5,0xde,
  0xf0,0x42,0xc0,0xcc,0xd9,0x83,0x52,0x76,0x39,0xdd,0x3c,0xb1,0xde,0x5b,0xe6,0x73,
  0xf,0xca,0x63,0xb0,0xde,0xe2,0x55,0x55,0xf8,0x71,0x1c,0xb3,0x2,0xcb,0xfb,0x3b,
  0x5,0x46,0x6e,0xc9,0x58,0x72,0x64,0xa,0x2c,0x46,0x23,0x98,0xbb,0x5e,0xee,0x83,
  0x3d,0x23,0x2b,0x18,0x86,0x1,0x31,0x46,0x2c,0x97,0xcb,0x97,0x3d,0x98,0x2f,0x53,
  0xf9,0x2f,0xf,0x32,0x2,0x11,0xc9,0xcc,0x66,0x52,0x89,0x9f,0xcc,0xcc,0x29,0xa4,
  0x94,0xe0,0xbd,0x87,0xaa,0xe6,0x6d,0x9b,0x4b,0x9f,0x1b,0x4c,0x44,0xf0,0x0,0x10,
  0x42,0xf8,0x6c,0xdb,0xf6,0xdf,0xe9,0x74,0x7a,0x7,0x20,0xf3,0xa5,0x99,0x25,0x41,
  0x97,0xcb,0xa5,0x25,0x22,0xe9,0xba,0xe,0xe,0x0,0xb6,0xdb,0x2d,0x0,0xd4,0xce,
  0xb9,0xc6,0x4c,0xfa,0xd,0xe3,0x38,0xc6,0xae,0xeb,0xae,0x44,0x24,0x5f,0x2d,0xf1,
  0x20,0x90,0x8f,0x6f,0x3f,0xe9,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,0xae,0x42,
  0x60,0x82,
    // /usr/src/ports/juffed/juffed-0.10-3.i686/src/juffed-0.10/plugins/doclist/edit-clear.png
  0x0,0x0,0x3,0x5,
  0x89,
  0x50,0x4e,0x47,0xd,0xa,0x1a,0xa,0x0,0x0,0x0,0xd,0x49,0x48,0x44,0x52,0x0,
  0x0,0x0,0x10,0x0,0x0,0x0,0x10,0x8,0x6,0x0,0x0,0x0,0x1f,0xf3,0xff,0x61,
  0x0,0x0,0x0,0x4,0x73,0x42,0x49,0x54,0x8,0x8,0x8,0x8,0x7c,0x8,0x64,0x88,
  0x0,0x0,0x0,0x19,0x74,0x45,0x58,0x74,0x53,0x6f,0x66,0x74,0x77,0x61,0x72,0x65,
  0x0,0x77,0x77,0x77,0x2e,0x69,0x6e,0x6b,0x73,0x63,0x61,0x70,0x65,0x2e,0x6f,0x72,
  0x67,0x9b,0xee,0x3c,0x1a,0x0,0x0,0x2,0x97,0x49,0x44,0x41,0x54,0x38,0x8d,0x95,
  0x92,0x4b,0x68,0x94,0x67,0x14,0x86,0x9f,0xef,0x9b,0x99,0xe8,0x4c,0x12,0x9b,0xdb,
  0x48,0x42,0x93,0x48,0xbc,0xd5,0xa8,0x14,0x2b,0x26,0x8b,0xa,0xd2,0x82,0x8b,0x4a,
  0x4b,0x76,0x82,0x97,0x85,0x8b,0xd1,0x8d,0x82,0x22,0xfc,0xb,0x5,0x5d,0x18,0x17,
  0x6,0x1c,0x90,0x52,0x10,0x84,0x8e,0xc6,0x85,0x60,0x4b,0x75,0xa1,0xb,0xe9,0x8d,
  0x16,0x31,0x2d,0xb4,0x69,0x34,0x31,0x8a,0x31,0x8d,0x9a,0x71,0x46,0x49,0x93,0xc9,
  0x65,0xcc,0x3f,0xf3,0x4f,0xfe,0xff,0xfb,0x8e,0x2b,0x45,0x63,0x21,0xf8,0xac,0xcf,
  0xfb,0x70,0xce,0xcb,0x51,0x47,0xbe,0x60,0x73,0x38,0xc4,0x5,0x11,0xa2,0xc6,0xb2,
  0xf7,0xd4,0xd,0xf9,0x91,0xf7,0x40,0x87,0x34,0xdf,0xaf,0x6d,0x8e,0xad,0xda,0xb0,
  0xa2,0xbc,0x31,0xa4,0xb9,0x7a,0x74,0x9b,0xda,0xfa,0x5e,0x2,0x60,0x71,0x45,0x54,
  0xb3,0xb4,0x2a,0xc2,0xc7,0x2d,0xb1,0x58,0x48,0x73,0xf6,0xf4,0x7e,0xa5,0x53,0x49,
  0xd5,0x99,0x4a,0xaa,0xda,0x5,0x5,0x56,0xe8,0x1c,0x7c,0x52,0x74,0x7d,0x23,0xd4,
  0xd7,0x94,0x11,0x5d,0xac,0xea,0xab,0x1a,0xe9,0x5,0x8e,0x3,0x4b,0x17,0x14,0x88,
  0xf0,0x8d,0xeb,0x99,0x8b,0xb7,0x6,0xf3,0xee,0x4c,0xc9,0xa7,0xa9,0x9d,0xca,0x95,
  0xad,0x1b,0x37,0xc4,0xe3,0x4d,0x2f,0x80,0xba,0x85,0x4,0x4a,0x44,0x0,0xe8,0xda,
  0xa7,0x4e,0xc4,0x57,0x72,0xfc,0x93,0xb6,0xcf,0x55,0x73,0x4b,0x3b,0x3d,0xa7,0xbb,
  0xbd,0xe9,0x7f,0xc6,0x72,0xec,0x54,0x93,0xc6,0xc8,0x25,0x11,0xce,0x27,0x1c,0x19,
  0xff,0x5f,0x41,0x2a,0xa9,0x76,0x69,0xad,0xbe,0xfd,0x74,0x73,0x47,0xb4,0xae,0xae,
  0x81,0x7f,0xbf,0xfe,0x9b,0xa7,0x57,0x1f,0xb2,0xfe,0xec,0x76,0x6a,0xd7,0x55,0x91,
  0x1e,0xed,0xf7,0xee,0xdf,0xfd,0x43,0x8c,0xf5,0xbe,0x33,0x46,0x8e,0x25,0x1c,0xc9,
  0xce,0x17,0xec,0xd1,0x9a,0x64,0x53,0x7d,0x6b,0x39,0x97,0x24,0x6a,0x26,0x5d,0xb6,
  0x74,0x6f,0x65,0x51,0x8d,0x6,0x15,0x85,0x50,0x35,0x7e,0x50,0xce,0xbd,0xc1,0x5f,
  0xfd,0x81,0xfe,0xdf,0xd,0xe2,0xff,0x60,0xc,0x29,0xe0,0xe6,0xeb,0x13,0x52,0x49,
  0xb5,0x28,0x72,0x8e,0x3b,0x15,0xcd,0xb5,0xab,0x3a,0x2e,0x1f,0xe,0x69,0xfd,0x1c,
  0x42,0xd,0x60,0xc6,0xc0,0x64,0xb1,0x41,0x1e,0xcf,0xb6,0xe0,0xcd,0xd5,0x90,0xc9,
  0xc,0xc8,0xe3,0x91,0x1,0x77,0x6a,0x32,0x5b,0xd4,0xaf,0x56,0x49,0x38,0x52,0xf2,
  0x77,0xd3,0x55,0x7b,0xb0,0xb1,0xa4,0x23,0x65,0x60,0x67,0x21,0x18,0x1,0x93,0x5,
  0xf3,0x1f,0x5e,0xe1,0x19,0xb3,0xb9,0xeb,0xcc,0x8c,0x9d,0x23,0x5e,0x8d,0xda,0xd4,
  0xfe,0x55,0x85,0x56,0x4a,0xc2,0x6f,0x35,0x52,0xc1,0xcf,0xd9,0x4c,0x5a,0x5b,0xab,
  0x50,0xfe,0x8,0x22,0x3e,0xfe,0x9c,0x87,0x57,0x9a,0xa5,0x58,0x98,0xa1,0x50,0x98,
  0x46,0x44,0xd0,0xe1,0x4a,0xd2,0x4f,0x7a,0x3,0x94,0xfc,0xa6,0xdf,0xcc,0x27,0x1c,
  0x79,0xe6,0xcf,0x4d,0x8f,0xa4,0xd3,0x77,0x99,0x71,0x63,0x4c,0x4c,0x8c,0x92,0xcb,
  0xa5,0x99,0xcc,0x65,0x70,0xdd,0x29,0x44,0x84,0x58,0xf5,0x36,0xa,0x45,0xcd,0xd0,
  0x83,0xfe,0x92,0x31,0x38,0x6f,0x9,0x0,0x2,0x23,0x87,0xfa,0x7a,0x7f,0x29,0xfa,
  0xac,0xc6,0x75,0x3d,0x8a,0xc5,0x3c,0xd6,0x6,0xe8,0x70,0xd,0x95,0xf1,0x1d,0xe4,
  0xdd,0x98,0xdc,0xba,0x79,0x25,0x6f,0x4c,0xf0,0x65,0xc2,0x91,0xcc,0xeb,0x12,0xdf,
  0xa4,0xfb,0x8c,0xea,0x59,0xfd,0x51,0x7b,0xdb,0xf2,0x15,0xad,0x11,0x2f,0xff,0x27,
  0x65,0xb1,0x35,0xe8,0xc8,0x32,0x1e,0xd,0xf7,0x4,0x43,0x43,0x7d,0xe3,0xd6,0xf2,
  0x59,0xc2,0x91,0x87,0x0,0xe1,0x77,0xd2,0x80,0x31,0x74,0xc,0x3d,0xf8,0xeb,0x76,
  0xe5,0x92,0x86,0xf,0x3f,0xa8,0x6a,0xd3,0xa3,0xa3,0xf7,0xfc,0xe1,0xe1,0x9f,0x2,
  0x6b,0xbc,0xeb,0xd6,0x72,0x20,0xe1,0xc8,0xc4,0x3b,0x9f,0x38,0x9f,0x54,0x52,0x2d,
  0x53,0x8a,0x3e,0xa5,0x10,0xe0,0x9a,0xb5,0x9c,0x4c,0x38,0xf2,0x78,0xfe,0xdc,0x4b,
  0x7e,0x7,0x43,0x8,0x28,0x84,0x12,0xda,0x0,0x0,0x0,0x0,0x49,0x45,0x4e,0x44,
  0xae,0x42,0x60,0x82,
  
};

static const unsigned char qt_resource_name[] = {
  // doc_icon
  0x0,0x8,
  0x5,0x95,0xf7,0x3e,
  0x0,0x64,
  0x0,0x6f,0x0,0x63,0x0,0x5f,0x0,0x69,0x0,0x63,0x0,0x6f,0x0,0x6e,
    // clear
  0x0,0x5,
  0x0,0x6a,0x2b,0x82,
  0x0,0x63,
  0x0,0x6c,0x0,0x65,0x0,0x61,0x0,0x72,
  
};

static const unsigned char qt_resource_struct[] = {
  // :
  0x0,0x0,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x2,0x0,0x0,0x0,0x1,
  // :/clear
  0x0,0x0,0x0,0x16,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x1,0xe7,
  // :/doc_icon
  0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,0x0,

};

QT_BEGIN_NAMESPACE

extern Q_CORE_EXPORT bool qRegisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

extern Q_CORE_EXPORT bool qUnregisterResourceData
    (int, const unsigned char *, const unsigned char *, const unsigned char *);

QT_END_NAMESPACE


int QT_MANGLE_NAMESPACE(qInitResources_doclistplugin)()
{
    QT_PREPEND_NAMESPACE(qRegisterResourceData)
        (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_CONSTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qInitResources_doclistplugin))

int QT_MANGLE_NAMESPACE(qCleanupResources_doclistplugin)()
{
    QT_PREPEND_NAMESPACE(qUnregisterResourceData)
       (0x01, qt_resource_struct, qt_resource_name, qt_resource_data);
    return 1;
}

Q_DESTRUCTOR_FUNCTION(QT_MANGLE_NAMESPACE(qCleanupResources_doclistplugin))
